from .flask_compress import Compress

# _version.py is generated by setuptools_scm when building the package, it is not versioned.
# If missing, this means that the imported code was most likely the git repository, that was
# installed without the "editable" mode.
try:
    from ._version import __version__
except ImportError:
    __version__ = "0"
